import { KuzzleRequest, User } from "kuzzle";
import { JSONObject, KDocument, KHit, SearchResult, mReplaceResponse } from "kuzzle-sdk";
import { DeviceManagerPlugin } from "../plugin";
import { DigitalTwinService, Metadata, SearchParams } from "../shared";
import { AssetHistoryService } from "./AssetHistoryService";
import { ApiAssetMigrateTenantResult, ApiAssetUpdateModelLocales } from "./types/AssetApi";
import { AssetContent } from "./types/AssetContent";
export declare class AssetService extends DigitalTwinService {
    private assetHistoryService;
    constructor(plugin: DeviceManagerPlugin, assetHistoryService: AssetHistoryService);
    registerAskEvents(): void;
    get(engineId: string, assetId: string, request: KuzzleRequest): Promise<KDocument<AssetContent>>;
    /**
     * Update an asset metadata
     */
    update(engineId: string, assetId: string, metadata: Metadata, request: KuzzleRequest): Promise<KDocument<AssetContent>>;
    /**
     * Replace an asset metadata
     */
    replaceMetadata(engineId: string, assetId: string, metadata: Metadata, request: KuzzleRequest): Promise<KDocument<AssetContent>>;
    /**
     * Update or Create an asset metadata
     */
    upsert(engineId: string, model: string, reference: string, metadata: Metadata, request: KuzzleRequest): Promise<KDocument<AssetContent>>;
    private _create;
    /**
     * Create an asset metadata
     */
    create(engineId: string, model: string, reference: string, metadata: JSONObject, request: KuzzleRequest): Promise<KDocument<AssetContent>>;
    /**
     * Delete an asset metadata
     */
    delete(engineId: string, assetId: string, request: KuzzleRequest): Promise<void>;
    search(engineId: string, searchParams: SearchParams, request: KuzzleRequest): Promise<SearchResult<KHit<AssetContent>>>;
    migrateTenant(user: User, assetsList: string[], engineId: string, newEngineId: string): Promise<ApiAssetMigrateTenantResult>;
    /**
     * Replace an asset metadata
     */
    mReplaceAndHistorize(engineId: string, assets: KDocument<AssetContent>[], removedMetadata: string[], { refresh }: {
        refresh: any;
    }): Promise<mReplaceResponse>;
    /**
     * Retrieve locales with the specified model and search all assets related to the model to update the locales.
     * The operation is historized.
     * @param request
     * @param engineGroup
     * @param model
     */
    updateModelLocales(request: KuzzleRequest, engineGroup: string, model: string): Promise<ApiAssetUpdateModelLocales[]>;
    private getEngine;
    private refreshModel;
}
