import { ControllerDefinition, KuzzleRequest } from "kuzzle";
import { DeviceManagerPlugin } from "../plugin";
import { AssetService } from "./AssetService";
import { ApiAssetCreateResult, ApiAssetUpsertResult, ApiAssetDeleteResult, ApiAssetGetMeasuresResult, ApiAssetGetResult, ApiAssetSearchResult, ApiAssetUpdateResult, ApiAssetMigrateTenantResult, ApiAssetMetadataReplaceResult, ApiAssetGetLastMeasuresResult, ApiAssetMGetLastMeasuredAtResult, ApiAssetMGetLastMeasuresResult, ApiAssetGetLastMeasuredAtResult, ApiAssetUpdateModelLocales } from "./types/AssetApi";
export declare class AssetsController {
    private plugin;
    private assetService;
    definition: ControllerDefinition;
    private exporter;
    private measureExporter;
    constructor(plugin: DeviceManagerPlugin, assetService: AssetService);
    get(request: KuzzleRequest): Promise<ApiAssetGetResult>;
    upsert(request: KuzzleRequest): Promise<ApiAssetUpsertResult>;
    update(request: KuzzleRequest): Promise<ApiAssetUpdateResult>;
    replaceMetadata(request: KuzzleRequest): Promise<ApiAssetMetadataReplaceResult>;
    create(request: KuzzleRequest): Promise<ApiAssetCreateResult>;
    delete(request: KuzzleRequest): Promise<ApiAssetDeleteResult>;
    search(request: KuzzleRequest): Promise<ApiAssetSearchResult>;
    getMeasures(request: KuzzleRequest): Promise<ApiAssetGetMeasuresResult>;
    getLastMeasures(request: KuzzleRequest): Promise<ApiAssetGetLastMeasuresResult>;
    mGetLastMeasures(request: KuzzleRequest): Promise<ApiAssetMGetLastMeasuresResult>;
    /**
     *
     * @param indexId The asset index
     * @param assetId The target asset ID
     * @param measureName The measureName to get the type from
     * @param engineGroup The target engine group
     * @returns The measure type if used in the asset, null otherwise
     * @throws If the asset does not exists
     */
    private getTypeFromMeasureSlot;
    mMeasureIngest(request: KuzzleRequest): Promise<void>;
    measureIngest(request: KuzzleRequest): Promise<void>;
    exportMeasures(request: KuzzleRequest): Promise<any>;
    export(request: KuzzleRequest): Promise<any>;
    migrateTenant(request: KuzzleRequest): Promise<ApiAssetMigrateTenantResult>;
    getLastMeasuredAt(request: KuzzleRequest): Promise<ApiAssetGetLastMeasuredAtResult>;
    mGetLastMeasuredAt(request: KuzzleRequest): Promise<ApiAssetMGetLastMeasuredAtResult>;
    /**
     * Update modelLocales of all assets related to the specified asset model.
     * This operation is done to make the search assets feature  up to date
     * @param request
     */
    updateModelLocales(request: KuzzleRequest): Promise<ApiAssetUpdateModelLocales[]>;
}
