"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DecodersController = void 0;
class DecodersController {
    constructor(payloadService, decodersRegister) {
        this.payloadService = payloadService;
        this.decodersRegister = decodersRegister;
        this.definition = {
            actions: {
                list: {
                    handler: this.list.bind(this),
                    http: [{ path: "device-manager/decoders", verb: "get" }],
                },
                prunePayloads: {
                    handler: this.prunePayloads.bind(this),
                    http: [
                        { path: "device-manager/decoders/_prunePayloads", verb: "delete" },
                    ],
                },
            },
        };
    }
    /**
     * List all available decoders
     */
    async list() {
        const decoders = this.decodersRegister.list();
        return { decoders };
    }
    /**
     * Clean payload collection for a time period
     */
    async prunePayloads(request) {
        const days = request.getBodyNumber("days");
        const deviceModel = request.input.body.deviceModel;
        const onlyValid = request.input.body.onlyValid ?? true;
        const deleted = await this.payloadService.prune(days, onlyValid, {
            deviceModel,
        });
        return { deleted };
    }
}
exports.DecodersController = DecodersController;
//# sourceMappingURL=DecodersController.js.map