import { PluginContext } from "kuzzle";
import { DeviceManagerPlugin } from "../plugin";
import { Decoder } from "./Decoder";
import { DecoderContent } from "./exports";
export declare class DecodersRegister {
    private context;
    private plugin;
    /**
     * Map<deviceModel, Decoder>
     */
    private _decoders;
    private get sdk();
    get decoders(): Decoder[];
    init(plugin: DeviceManagerPlugin, context: PluginContext): void;
    get(deviceModel: string): Decoder;
    list(): DecoderContent[];
    /**
     * Registers a new decoder for a device model.
     * Decoder and device models share a 1:1 relationship
     *
     * This will register a new API action:
     *  - controller: `device-manager/payload`
     *  - action: `action` property of the decoder or the device model in kebab-case
     *
     * @param decoder Instantiated decoder
     *
     * @returns Corresponding API action requestPayload
     */
    register(decoder: Decoder): {
        action: string;
        controller: string;
    };
    printDecoders(): void;
    /**
     * Register default role, profile and user associated to the generated actions
     * in the Payload controller.
     */
    registerDefaultRights(): void;
    private registerDefaultUser;
    private registerDefaultProfile;
    private registerDefaultRole;
}
