"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PayloadsController = void 0;
class PayloadsController {
    constructor(payloadService, decodersRegister) {
        this.payloadService = payloadService;
        this.decodersRegister = decodersRegister;
        this.definition = {
            actions: {
                receiveUnknown: {
                    handler: this.receiveUnknown.bind(this),
                    http: [
                        {
                            openapi: {
                                description: `Receive a payload from a device`,
                                parameters: [
                                    {
                                        in: "path",
                                        name: "deviceModel",
                                        required: true,
                                        schema: {
                                            type: "string",
                                        },
                                    },
                                    {
                                        in: "body",
                                        name: "payload",
                                        required: true,
                                        schema: {
                                            type: "object",
                                        },
                                    },
                                ],
                            },
                            path: "device-manager/payload/:deviceModel",
                            verb: "post",
                        },
                    ],
                },
            },
        };
        for (const decoder of this.decodersRegister.decoders) {
            this.definition.actions[decoder.action] = {
                handler: (request) => this.payloadService.receive(request, decoder),
                http: decoder.http,
            };
        }
    }
    async receiveUnknown(request) {
        const payload = request.getBody();
        const deviceModel = request.getString("deviceModel", "unknownModel");
        const apiAction = `${request.input.controller}:${request.input.action}`;
        await this.payloadService.receiveUnknown(deviceModel, payload, apiAction);
    }
}
exports.PayloadsController = PayloadsController;
//# sourceMappingURL=PayloadsController.js.map