import { ControllerDefinition, KuzzleRequest } from "kuzzle";
import { DeviceManagerPlugin } from "../plugin";
import { DeviceService } from "./DeviceService";
import { ApiDeviceAttachEngineResult, ApiDeviceCreateResult, ApiDeviceDeleteResult, ApiDeviceDetachEngineResult, ApiDeviceGetResult, ApiDeviceLinkAssetResult, ApiDeviceSearchResult, ApiDeviceUnlinkAssetResult, ApiDeviceUpdateResult, ApiDeviceGetMeasuresResult, ApiDeviceUpsertResult, ApiDeviceGetLastMeasuresResult, ApiDeviceMGetLastMeasuresResult, ApiDeviceGetLastMeasuredAtResult, ApiDeviceMGetLastMeasuredAtResult, ApiDeviceMetadataReplaceResult } from "./types/DeviceApi";
export declare class DevicesController {
    private plugin;
    private deviceService;
    definition: ControllerDefinition;
    private exporter;
    private measureExporter;
    constructor(plugin: DeviceManagerPlugin, deviceService: DeviceService);
    get(request: KuzzleRequest): Promise<ApiDeviceGetResult>;
    update(request: KuzzleRequest): Promise<ApiDeviceUpdateResult>;
    replaceMetadata(request: KuzzleRequest): Promise<ApiDeviceMetadataReplaceResult>;
    delete(request: KuzzleRequest): Promise<ApiDeviceDeleteResult>;
    search(request: KuzzleRequest): Promise<ApiDeviceSearchResult>;
    upsert(request: KuzzleRequest): Promise<ApiDeviceUpsertResult>;
    /**
     * Create and provision a new device
     */
    create(request: KuzzleRequest): Promise<ApiDeviceCreateResult>;
    /**
     * Attach a device to a tenant
     */
    attachEngine(request: KuzzleRequest): Promise<ApiDeviceAttachEngineResult>;
    /**
     * Detach a device from it's tenant
     */
    detachEngine(request: KuzzleRequest): Promise<ApiDeviceDetachEngineResult>;
    /**
     * Link a device to an asset.
     */
    linkAsset(request: KuzzleRequest): Promise<ApiDeviceLinkAssetResult>;
    /**
     * Unlink a device from an asset.
     */
    unlinkAsset(request: KuzzleRequest): Promise<ApiDeviceUnlinkAssetResult>;
    getMeasures(request: KuzzleRequest): Promise<ApiDeviceGetMeasuresResult>;
    getLastMeasures(request: KuzzleRequest): Promise<ApiDeviceGetLastMeasuresResult>;
    mGetLastMeasures(request: KuzzleRequest): Promise<ApiDeviceMGetLastMeasuresResult>;
    exportMeasures(request: KuzzleRequest): Promise<any>;
    receiveMeasures(request: KuzzleRequest): Promise<void>;
    export(request: KuzzleRequest): Promise<any>;
    getLastMeasuredAt(request: KuzzleRequest): Promise<ApiDeviceGetLastMeasuredAtResult>;
    mGetLastMeasuredAt(request: KuzzleRequest): Promise<ApiDeviceMGetLastMeasuredAtResult>;
}
