import { KuzzleRequest } from "kuzzle";
import { JSONObject, KDocument, KHit, SearchResult } from "kuzzle-sdk";
import { DeviceManagerPlugin } from "../plugin";
import { BaseService, SearchParams } from "../shared";
import { AssetModelContent, DeviceModelContent, GroupModelContent, LocaleDetails, MeasureModelContent, MetadataDetails, MetadataGroups, MetadataMappings, TooltipModels } from "./types/ModelContent";
import { SchemaObject } from "ajv";
import { MeasureValuesDetails } from "../measure";
import { NamedMeasures } from "../decoder";
export declare class ModelService extends BaseService {
    constructor(plugin: DeviceManagerPlugin);
    registerAskEvents(): void;
    private checkModelsConflicts;
    writeAsset(engineGroup: string, model: string, metadataMappings: MetadataMappings, defaultMetadata: JSONObject, metadataDetails: MetadataDetails, metadataGroups: MetadataGroups, measures: NamedMeasures, tooltipModels: TooltipModels, locales: {
        [valueName: string]: LocaleDetails;
    }): Promise<KDocument<AssetModelContent>>;
    private checkDefaultValues;
    writeDevice(model: string, metadataMappings: MetadataMappings, defaultMetadata: JSONObject, metadataDetails: MetadataDetails, metadataGroups: MetadataGroups, measures: NamedMeasures): Promise<KDocument<DeviceModelContent>>;
    writeGroup(engineGroup: string, model: string, metadataMappings: MetadataMappings, defaultMetadata: JSONObject, metadataDetails: MetadataDetails, metadataGroups: MetadataGroups): Promise<KDocument<GroupModelContent>>;
    writeMeasure(type: string, valuesMappings: JSONObject, validationSchema?: SchemaObject, valuesDetails?: MeasureValuesDetails, locales?: {
        [valueName: string]: LocaleDetails;
    }): Promise<KDocument<MeasureModelContent>>;
    deleteAsset(_id: string): Promise<void>;
    deleteDevice(_id: string): Promise<void>;
    deleteGroup(_id: string): Promise<void>;
    deleteMeasure(_id: string): Promise<void>;
    listAsset(engineGroup: string): Promise<KDocument<AssetModelContent>[]>;
    listDevices(): Promise<KDocument<DeviceModelContent>[]>;
    listGroups(engineGroup: string): Promise<KDocument<GroupModelContent>[]>;
    listMeasures(): Promise<KDocument<MeasureModelContent>[]>;
    searchAssets(engineGroup: string, searchParams: Partial<SearchParams>): Promise<SearchResult<KHit<AssetModelContent>>>;
    searchDevices(searchParams: Partial<SearchParams>): Promise<SearchResult<KHit<DeviceModelContent>>>;
    searchGroups(engineGroup: string, searchParams: Partial<SearchParams>): Promise<SearchResult<KHit<GroupModelContent>>>;
    searchMeasures(searchParams: Partial<SearchParams>): Promise<SearchResult<KHit<MeasureModelContent>>>;
    assetExists(model: string): Promise<boolean>;
    deviceExists(model: string): Promise<boolean>;
    getAsset(engineGroup: string, model: string): Promise<KDocument<AssetModelContent>>;
    getDevice(model: string): Promise<KDocument<DeviceModelContent>>;
    getGroup(model: string): Promise<KDocument<GroupModelContent>>;
    getMeasure(type: string): Promise<KDocument<MeasureModelContent>>;
    /**
     * Update an asset model
     */
    updateAsset(engineGroup: string, model: string, metadataMappings: MetadataMappings, defaultMetadata: JSONObject, metadataDetails: MetadataDetails, metadataGroups: MetadataGroups, measures: AssetModelContent["asset"]["measures"], tooltipModels: TooltipModels, locales: {
        [valueName: string]: LocaleDetails;
    }, request: KuzzleRequest): Promise<KDocument<AssetModelContent>>;
}
