import { TwinModelContent, TwinType } from "../plugin";
import { GroupModelContent, MeasureModelContent } from "./exports";
export type ConflictChunk = {
    sourceModel: string;
    newModel: string;
    modelType: string;
    conflicts: MappingsConflict[];
};
export type MappingsConflict = {
    path: string;
    currentType: string | undefined;
    newType: string | undefined;
};
/**
 * Return every conflicts between the mappings of twins and a new twin model
 *
 * @param twinType The target twin type
 * @param models The already present twin models
 * @param additional The new asset
 * @returns An array of ConflictChunk between current twins and the new twin
 */
export declare function getTwinConflicts<TDigitalTwin extends TwinModelContent>(twinType: TwinType, models: TDigitalTwin[], additional: TDigitalTwin): ConflictChunk[];
/**
 * Return every conflicts between the mappings of group models and a new group model
 *
 * @param groups The already present group models
 * @param additional The new group model
 * @returns An array of ConflictChunk between current groups and the new group
 */
export declare function getGroupConflicts(measures: GroupModelContent[], additional: GroupModelContent): ConflictChunk[];
/**
 * Return every conflicts between the mappings of measure models and a new measure model
 *
 * @param measures The already present measure models
 * @param additional The new measure
 * @returns An array of ConflictChunk between current measures and the new measure
 */
export declare function getMeasureConflicts(measures: MeasureModelContent[], additional: MeasureModelContent): ConflictChunk[];
