import { ArgsDocumentControllerCreate, ArgsDocumentControllerDelete, ArgsDocumentControllerUpdate, Backend, EmbeddedSDK, KDocument, KDocumentContent, KHit, KuzzleRequest, SearchResult, User } from "kuzzle";
import { DeviceManagerPlugin, DeviceManagerConfiguration, InternalCollection } from "../../plugin";
interface PayloadRequest {
    collection: InternalCollection;
    engineId: string;
}
export type SearchParams = ReturnType<KuzzleRequest["getSearchParams"]>;
export declare abstract class BaseService {
    private plugin;
    constructor(plugin: DeviceManagerPlugin);
    protected get app(): Backend;
    protected get sdk(): EmbeddedSDK;
    protected get config(): DeviceManagerConfiguration;
    protected get impersonatedSdk(): (user: User) => EmbeddedSDK;
    protected normalizeKuzzleRequest(request: KuzzleRequest, { collection, engineId }: PayloadRequest): KuzzleRequest;
    /**
     * Wrapper to SDK create method with trigger generic:document events
     *
     * @param {KuzzleRequest} request
     * @param {KDocument} documentId
     * @param {PayloadRequest} payload
     * @param {ArgsDocumentControllerCreate} [options]
     * @returns {Promise<KDocument>}
     */
    protected getDocument<T extends KDocumentContent = KDocumentContent>(request: KuzzleRequest, documentId: string, { collection, engineId }: PayloadRequest, options?: ArgsDocumentControllerCreate): Promise<KDocument<T>>;
    /**
     * Wrapper to SDK create method with trigger generic:document events
     *
     * @param {KuzzleRequest} request
     * @param {KDocument} document
     * @param {PayloadRequest} payload
     * @param {ArgsDocumentControllerCreate} [options]
     * @returns {Promise<KDocument>}
     */
    protected createDocument<T extends KDocumentContent = KDocumentContent>(request: KuzzleRequest, document: KDocument<T>, { collection, engineId }: PayloadRequest, options?: ArgsDocumentControllerCreate): Promise<KDocument<T>>;
    /**
     * Wrapper to SDK update method with trigger generic:document events
     *
     * @param {KuzzleRequest} request
     * @param {KDocument} document
     * @param {PayloadRequest} payload
     * @param {ArgsDocumentControllerUpdate} [options]
     * @returns {Promise<KDocument>}
     */
    protected updateDocument<T extends KDocumentContent = KDocumentContent>(request: KuzzleRequest, document: KDocument<Partial<T>>, { collection, engineId }: PayloadRequest, options?: ArgsDocumentControllerUpdate): Promise<KDocument<T>>;
    /**
     * Wrapper to SDK delete method with trigger generic:document events
     *
     * @param {KuzzleRequest} request
     * @param {string} documentId
     * @param {PayloadRequest} payload
     * @param {ArgsDocumentControllerUpdate} [options]
     * @returns {Promise<{ _id: string }>}
     */
    protected deleteDocument(request: KuzzleRequest, documentId: string, { collection, engineId }: PayloadRequest, options?: ArgsDocumentControllerDelete): Promise<{
        _id: string;
    }>;
    /**
     * Wrapper to SDK search method with trigger generic:document events
     * ! Caution the pipes are not applied on next()
     *
     * @param {KuzzleRequest} request
     * @param {ArgsDocumentControllerUpdate} [options]
     * @param {PayloadRequest} payload
     * @returns {Promise<SearchResult<KHit>>}
     */
    protected searchDocument<T extends KDocumentContent = KDocumentContent>(request: KuzzleRequest, { from, size, scrollTTL: scroll }: SearchParams, { collection, engineId }: PayloadRequest): Promise<SearchResult<KHit<T>>>;
}
export {};
