"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAJVErrors = exports.getValidator = exports.addSchemaToCache = void 0;
const ajv_formats_1 = __importDefault(require("ajv-formats"));
const ajv_1 = __importDefault(require("ajv"));
/**
 * TODO: add stricter TypeScript rules to allow the use of JSONSchemaType
 */
const ajv = (0, ajv_formats_1.default)(new ajv_1.default({}), [
    "date-time",
    "time",
    "date",
    "email",
    "hostname",
    "ipv4",
    "ipv6",
    "uri",
    "uri-reference",
    "uuid",
    "uri-template",
    "json-pointer",
    "relative-json-pointer",
    "regex",
]);
/**
 * Compile and add the schema to the AJV cache
 *
 * @param scemaID The schema unique identifier
 * @param schema The schema to add
 *
 * @returns The newly created validator for the schema
 * @throws If the provided schema is not valid
 */
function addSchemaToCache(schemaID, schema) {
    ajv.validateSchema(schema, true);
    ajv.removeSchema(schemaID);
    return ajv.addSchema(schema, schemaID);
}
exports.addSchemaToCache = addSchemaToCache;
/**
 * Search the corresponding validator in the AJV cache.
 *
 * @param schemaID The desired schema identifier
 *
 * @returns The desired schema validator
 * @throws If the schema cannot be found
 */
function getValidator(schemaID) {
    return ajv.getSchema(schemaID);
}
exports.getValidator = getValidator;
/**
 * Get and return the previous AJV errors
 *
 * @returns an array of ErrorObject
 */
function getAJVErrors() {
    return ajv.errors ?? [];
}
exports.getAJVErrors = getAJVErrors;
//# sourceMappingURL=AJValidator.js.map